summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmaparray_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmaparray_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmaparray_imp.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmaparray_imp.h b/kjsembed/qtbindings/qcanvaspixmaparray_imp.h
index c1dba541..32fd3d96 100644
--- a/kjsembed/qtbindings/qcanvaspixmaparray_imp.h
+++ b/kjsembed/qtbindings/qcanvaspixmaparray_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasPixmapArray;
+class TTQCanvasPixmapArray;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasPixmapArray;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasPixmapArray methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasPixmapArrayImp : public JSProxyImp
+class TQCanvasPixmapArrayImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -46,8 +46,8 @@ public:
Method_Last = -1
};
- QCanvasPixmapArrayImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasPixmapArrayImp();
+ TQCanvasPixmapArrayImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasPixmapArrayImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -61,16 +61,16 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasPixmapArray *toQCanvasPixmapArray( KJS::Object &object );
+ static TTQCanvasPixmapArray *toTQCanvasPixmapArray( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasPixmapArray_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasPixmapArray_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmapArray_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmapArray_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -100,7 +100,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasPixmapArray *instance; // Temp
+ TTQCanvasPixmapArray *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasPixmapArray;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasPixmapArray methods.
+ * Wrapper class for TTQCanvasPixmapArray methods.
*
* @author Richard Moore, rich@kde.org